# ChatGPT
- [ChatGPT](https://chat.openai.com/)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Disclaimer

We are not responsible if OpenAI bans your account for doing this. This may not be consistent with their rules to use their services in this way. This was developed for experimental purposes and we assume no responsibility for how you use it.

## Quick Start Guide

### Get your ChatGPT Token

1. Get your `accessToken` value from https://chat.openai.com/api/auth/session

### Update your agent settings
1. Update `CHATGPT_TOKEN` with the value of `accessToken` from https://chat.openai.com/api/auth/session .
2. `AI_MODEL` is `gpt-3.5-turbo` for ChatGPT.  If you have `gpt-4` access, you can set it to `gpt-4` instead, but it will limit you to 25 messages every 3 hours.